@@ -5,9 +5,6 @@
 import os
 import pickle
 import subprocess
-import sys
-from pylammpsmpi.commands import command_list, thermo_list, func_list, prop_list
-
 
 
 __author__ = "Sarath Menon, Jan Janssen"
@@ -26,6 +23,7 @@ class LammpsBase:
     def __init__(self, cores=8, working_directory="."):
         self.cores = cores
         self.working_directory = working_directory
+        self._process = None
 
     def start_process(self):
         executable = os.path.join(
@@ -109,13 +107,11 @@ class LammpsBase:
         self._send(command="get_file", data=[inputfile])
         _ = self._receive()
 
-
     #TODO
     def extract_setting(self, *args):
         self._send(command="extract_setting", data=list(args))
         return self._receive()
 
-
     def extract_global(self, name, type):
         """
         Extract value of global simulation parameters
@@ -196,7 +192,6 @@ class LammpsBase:
         self._send(command="extract_atom", data=list([name]))
         return self._receive()
 
-
     def extract_fix(self, *args):
         """
         Extract a fix value
@@ -301,7 +296,6 @@ class LammpsBase:
         self._send(command="set_variable", data=list(args))
         return self._receive()
 
-
     def reset_box(self, *args):
         """
         Reset the simulation box
@@ -366,7 +360,6 @@ class LammpsBase:
         else:
             raise TypeError("Value of x cannot be None")
 
-
     @property
     def has_exceptions(self):
         """ Return whether the LAMMPS shared library was compiled with C++ exceptions handling enabled """
@@ -497,9 +490,6 @@ class LammpsBase:
             self._send(command="command", data=cmd)
             _ = self._receive()
 
-
-
-
     def gather_atoms(self, *args, concat=False, ids=None):
         """
         Gather atom properties
@@ -544,7 +534,6 @@ class LammpsBase:
             self._send(command="gather_atoms", data=list(args))
         return self._receive()
 
-
     def scatter_atoms(self, *args, ids=None):
         """
         Scatter atoms for the lammps library
@@ -618,7 +607,6 @@ class LammpsBase:
         self._send(command="extract_compute", data=args)
         return self._receive()
 
-
     def close(self):
         """
         Close the current lammps object
